@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_cached.c,v 1.43 2004/11/21 21:53:32 hoa Exp $
+ * $Id: imapdriver_cached.c,v 1.44 2005/01/29 15:40:23 hoa Exp $
  */
 
 #include "imapdriver_cached.h"
@@ -871,10 +871,16 @@ static int imapdriver_cached_get_messages_list(mailsession * session,
     mailmessage * msg;
     
     msg = carray_get(env_list->msg_tab, i);
-    if (msg->msg_index < uid_max + 1)
+    if (msg->msg_index < uid_max + 1) {
+      mailmessage * msg;
+      
+      msg = carray_get(env_list->msg_tab, i);
+      mailmessage_free(msg);
       carray_delete(env_list->msg_tab, i);
-    else
+    }
+    else {
       i ++;
+    }
   }
   
   tab = carray_new(carray_count(env_list->msg_tab) +
