@@ -30,10 +30,16 @@
  */
 
 /*
- * $Id: mailengine.c,v 1.5 2004/11/21 21:53:35 hoa Exp $
+ * $Id: mailengine.c,v 1.7 2005/01/31 01:07:50 hoa Exp $
  */
 
 #include "mailengine.h"
+
+#ifndef CONFIG_H
+#define CONFIG_H
+#include "config.h"
+#endif
+
 #include "mailfolder.h"
 #include "maildriver.h"
 #include "imapdriver_cached.h"
