@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.21 2004/11/21 21:53:39 hoa Exp $
+ * $Id: mailpop3.c,v 1.22 2005/01/28 01:43:13 hoa Exp $
  */
 
 /*
@@ -721,7 +721,7 @@ int mailpop3_retr(mailpop3 * f, unsigned int index, char ** result,
 }
 
 int mailpop3_top(mailpop3 * f, unsigned int index,
-    uint32_t count, char ** result,
+    unsigned int count, char ** result,
     size_t * result_len)
 {
   char command[POP3_STRING_SIZE];
